/**
 * CSS files with the .module.css suffix will be treated as CSS modules
 * and scoped locally.
 */

.heroBanner {
  padding: 4rem 0 4rem;
  text-align: center;
  position: relative;
  overflow: hidden;
  background: linear-gradient(135deg, #0d1117 0%, #161b22 100%);
}

@media screen and (max-width: 996px) {
  .heroBanner {
    padding: 2rem 1rem 2rem;
  }
}

.buttons {
  display: flex;
  align-items: center;
  justify-content: center;
  gap: 1rem;
  flex-wrap: wrap;
  margin-top: 1.5rem;
  margin-bottom: 2rem;
}

.installCodeContainer {
  margin-top: 3rem;
  padding-top: 2rem;
  border-top: 1px solid rgba(255, 255, 255, 0.05);
}

.installCode {
  display: inline-flex;
  align-items: center;
  gap: 1rem;
  padding: 1rem 1.5rem;
  background: rgba(22, 27, 34, 0.8);
  border: 1px solid #30363d;
  border-radius: 0.75rem;
  box-shadow: 0 4px 12px rgba(0, 0, 0, 0.3);
  transition: all 0.2s ease;
}

.installCode:hover {
  background: rgba(22, 27, 34, 1);
  border-color: #60a5fa;
  box-shadow: 0 4px 20px rgba(96, 165, 250, 0.2);
}

.installCode code {
  font-size: 1rem;
  color: #e6edf3;
  font-family: ui-monospace, SFMono-Regular, 'SF Mono', Consolas, 'Liberation Mono', Menlo, monospace;
}
